pub struct ConfigMsg {
pub admins: Admins,
pub contracts: Contracts,
pub flow_type_config: Vec<FlowTypeConfigMsg>,
}Fields
admins: Adminscontracts: Contractsflow_type_config: Vec<FlowTypeConfigMsg>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ConfigMsg
impl<'de> Deserialize<'de> for ConfigMsg
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ConfigMsg
impl JsonSchema for ConfigMsg
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ConfigMsg