pub struct Contracts {
pub oracle_price_contract: Addr,
pub utilities_contract: Addr,
pub funds_distributor_contract: Addr,
}Fields
oracle_price_contract: Addrutilities_contract: Addrfunds_distributor_contract: AddrTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Contracts
impl<'de> Deserialize<'de> for Contracts
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Contracts
impl JsonSchema for Contracts
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreimpl Eq for Contracts
impl StructuralPartialEq for Contracts