pub struct FlowCreate {
pub flow_type: FlowType,
pub taker: Addr,
pub denom: String,
pub identifier: Option<String>,
pub genesis_time: u64,
pub schedules: Vec<FlowSchedule>,
}Fields
flow_type: FlowTypetaker: Addrdenom: Stringidentifier: Option<String>genesis_time: u64schedules: Vec<FlowSchedule>Trait Implementations
Sourceimpl Clone for FlowCreate
impl Clone for FlowCreate
Sourcefn clone(&self) -> FlowCreate
fn clone(&self) -> FlowCreate
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FlowCreate
impl Debug for FlowCreate
Sourceimpl<'de> Deserialize<'de> for FlowCreate
impl<'de> Deserialize<'de> for FlowCreate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FlowCreate
impl JsonSchema for FlowCreate
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for FlowCreate
impl PartialEq for FlowCreate
Sourceimpl Serialize for FlowCreate
impl Serialize for FlowCreate
impl StructuralPartialEq for FlowCreate