pub struct FlowSchedule {
pub start_time: u64,
pub end_time: u64,
pub cliff_end_time: u64,
pub amount: Uint128,
}Fields
start_time: u64end_time: u64cliff_end_time: u64amount: Uint128Trait Implementations
Sourceimpl Clone for FlowSchedule
impl Clone for FlowSchedule
Sourcefn clone(&self) -> FlowSchedule
fn clone(&self) -> FlowSchedule
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FlowSchedule
impl Debug for FlowSchedule
Sourceimpl<'de> Deserialize<'de> for FlowSchedule
impl<'de> Deserialize<'de> for FlowSchedule
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FlowSchedule
impl JsonSchema for FlowSchedule
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for FlowSchedule
impl PartialEq for FlowSchedule
Sourceimpl Serialize for FlowSchedule
impl Serialize for FlowSchedule
impl StructuralPartialEq for FlowSchedule