pub struct FlowTemplateCreate {
pub flow_type: FlowType,
pub genesis_time: u64,
pub maker: Option<Addr>,
pub identifier: Option<u64>,
pub schedules: Vec<FlowTemplateSchedule>,
}Fields
flow_type: FlowTypegenesis_time: u64maker: Option<Addr>identifier: Option<u64>schedules: Vec<FlowTemplateSchedule>Trait Implementations
Sourceimpl Clone for FlowTemplateCreate
impl Clone for FlowTemplateCreate
Sourcefn clone(&self) -> FlowTemplateCreate
fn clone(&self) -> FlowTemplateCreate
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FlowTemplateCreate
impl Debug for FlowTemplateCreate
Sourceimpl<'de> Deserialize<'de> for FlowTemplateCreate
impl<'de> Deserialize<'de> for FlowTemplateCreate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FlowTemplateCreate
impl JsonSchema for FlowTemplateCreate
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for FlowTemplateCreate
impl PartialEq for FlowTemplateCreate
Sourceimpl Serialize for FlowTemplateCreate
impl Serialize for FlowTemplateCreate
impl StructuralPartialEq for FlowTemplateCreate