pub struct FlowTypeConfigMsg {
pub flow_type: FlowType,
pub fee: Decimal,
pub partner_fee: Decimal,
pub fee_collectors: Vec<FeeCollector>,
}Fields
flow_type: FlowTypefee: Decimalpartner_fee: Decimalfee_collectors: Vec<FeeCollector>Trait Implementations
Sourceimpl Clone for FlowTypeConfigMsg
impl Clone for FlowTypeConfigMsg
Sourcefn clone(&self) -> FlowTypeConfigMsg
fn clone(&self) -> FlowTypeConfigMsg
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FlowTypeConfigMsg
impl Debug for FlowTypeConfigMsg
Sourceimpl<'de> Deserialize<'de> for FlowTypeConfigMsg
impl<'de> Deserialize<'de> for FlowTypeConfigMsg
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FlowTypeConfigMsg
impl JsonSchema for FlowTypeConfigMsg
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for FlowTypeConfigMsg
impl PartialEq for FlowTypeConfigMsg
Sourceimpl Serialize for FlowTypeConfigMsg
impl Serialize for FlowTypeConfigMsg
impl StructuralPartialEq for FlowTypeConfigMsg