pub struct ClaimableAmountResponse {
pub id: u64,
pub flow_type: FlowType,
pub denom: String,
pub taker: Addr,
pub claimable_amount: Uint128,
}Fields
id: u64flow_type: FlowTypedenom: Stringtaker: Addrclaimable_amount: Uint128Trait Implementations
Sourceimpl Clone for ClaimableAmountResponse
impl Clone for ClaimableAmountResponse
Sourcefn clone(&self) -> ClaimableAmountResponse
fn clone(&self) -> ClaimableAmountResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClaimableAmountResponse
impl Debug for ClaimableAmountResponse
Sourceimpl<'de> Deserialize<'de> for ClaimableAmountResponse
impl<'de> Deserialize<'de> for ClaimableAmountResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ClaimableAmountResponse
impl JsonSchema for ClaimableAmountResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ClaimableAmountResponse
impl PartialEq for ClaimableAmountResponse
Sourceimpl Serialize for ClaimableAmountResponse
impl Serialize for ClaimableAmountResponse
impl StructuralPartialEq for ClaimableAmountResponse