pub struct ExtendedFlowResponse {
pub id: u64,
pub flow_type: FlowType,
pub maker: Addr,
pub taker: Addr,
pub denom: String,
pub identifier: Option<String>,
pub genesis_time: u64,
pub schedules: Vec<ExtendedFlowSchedule>,
pub last_claim_time: u64,
}Fields
id: u64flow_type: FlowTypemaker: Addrtaker: Addrdenom: Stringidentifier: Option<String>genesis_time: u64schedules: Vec<ExtendedFlowSchedule>last_claim_time: u64Trait Implementations
Sourceimpl Clone for ExtendedFlowResponse
impl Clone for ExtendedFlowResponse
Sourcefn clone(&self) -> ExtendedFlowResponse
fn clone(&self) -> ExtendedFlowResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtendedFlowResponse
impl Debug for ExtendedFlowResponse
Sourceimpl<'de> Deserialize<'de> for ExtendedFlowResponse
impl<'de> Deserialize<'de> for ExtendedFlowResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExtendedFlowResponse
impl JsonSchema for ExtendedFlowResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExtendedFlowResponse
impl PartialEq for ExtendedFlowResponse
Sourceimpl Serialize for ExtendedFlowResponse
impl Serialize for ExtendedFlowResponse
impl StructuralPartialEq for ExtendedFlowResponse