pub struct StatisticsResponse {
pub stats_key: String,
pub stats_key_type: String,
pub stats_value: Option<Uint128>,
}Fields
stats_key: Stringstats_key_type: Stringstats_value: Option<Uint128>Trait Implementations
Sourceimpl Clone for StatisticsResponse
impl Clone for StatisticsResponse
Sourcefn clone(&self) -> StatisticsResponse
fn clone(&self) -> StatisticsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StatisticsResponse
impl Debug for StatisticsResponse
Sourceimpl<'de> Deserialize<'de> for StatisticsResponse
impl<'de> Deserialize<'de> for StatisticsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StatisticsResponse
impl JsonSchema for StatisticsResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for StatisticsResponse
impl PartialEq for StatisticsResponse
Sourceimpl Serialize for StatisticsResponse
impl Serialize for StatisticsResponse
impl Eq for StatisticsResponse
impl StructuralPartialEq for StatisticsResponse